package com.sooka.system.service.impl;

import java.util.List;

import com.sooka.common.annotation.DataSource;
import com.sooka.common.core.text.Convert;
import com.sooka.common.enums.DataSourceType;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.sooka.system.mapper.TgjjGrdkzhbdxxMapper;
import com.sooka.system.domain.TgjjGrdkzhbdxx;
import com.sooka.system.service.ITgjjGrdkzhbdxxService;

/**
 * 个人贷款账户变动信息Service业务层处理
 *
 * @author lei
 * @date 2021-11-16
 */
@Service

public class TgjjGrdkzhbdxxServiceImpl extends Guiji_Base_Service implements ITgjjGrdkzhbdxxService
{
    @Autowired
    private TgjjGrdkzhbdxxMapper tgjjGrdkzhbdxxMapper;

    /**
     * 查询个人贷款账户变动信息
     *
     * @param ID 个人贷款账户变动信息ID
     * @return 个人贷款账户变动信息
     */
    @Override
    public TgjjGrdkzhbdxx selectTgjjGrdkzhbdxxById(Long ID)
    {
        return tgjjGrdkzhbdxxMapper.selectTgjjGrdkzhbdxxById(ID);
    }

    /**
     * 查询个人贷款账户变动信息列表
     *
     * @param tgjjGrdkzhbdxx 个人贷款账户变动信息
     * @return 个人贷款账户变动信息
     */
    @Override
    public List<TgjjGrdkzhbdxx> selectTgjjGrdkzhbdxxList(TgjjGrdkzhbdxx tgjjGrdkzhbdxx)
    {
        List ls = tgjjGrdkzhbdxxMapper.selectTgjjGrdkzhbdxxList(tgjjGrdkzhbdxx);
        tgjjGrdkzhbdxx.setInterfaceinfoId("b4af4189-20b6-4e13-8fc6-ae307b9e3ea4");
        tgjjGrdkzhbdxx.setInterfaceinfoName("共享-市公积金-个人贷款变动信息");
        tgjjGrdkzhbdxx.setInterfacetype("platform_interfacetype_1");
        add_log(tgjjGrdkzhbdxx);
        return ls;
    }

    /**
     * 新增个人贷款账户变动信息
     *
     * @param tgjjGrdkzhbdxx 个人贷款账户变动信息
     * @return 结果
     */
    @Override
    public int insertTgjjGrdkzhbdxx(TgjjGrdkzhbdxx tgjjGrdkzhbdxx)
    {
        return tgjjGrdkzhbdxxMapper.insertTgjjGrdkzhbdxx(tgjjGrdkzhbdxx);
    }

    /**
     * 修改个人贷款账户变动信息
     *
     * @param tgjjGrdkzhbdxx 个人贷款账户变动信息
     * @return 结果
     */
    @Override
    public int updateTgjjGrdkzhbdxx(TgjjGrdkzhbdxx tgjjGrdkzhbdxx)
    {
        return tgjjGrdkzhbdxxMapper.updateTgjjGrdkzhbdxx(tgjjGrdkzhbdxx);
    }

    /**
     * 删除个人贷款账户变动信息对象
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteTgjjGrdkzhbdxxByIds(String ids)
    {
        return tgjjGrdkzhbdxxMapper.deleteTgjjGrdkzhbdxxByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除个人贷款账户变动信息信息
     *
     * @param ID 个人贷款账户变动信息ID
     * @return 结果
     */
    @Override
    public int deleteTgjjGrdkzhbdxxById(Long ID)
    {
        return tgjjGrdkzhbdxxMapper.deleteTgjjGrdkzhbdxxById(ID);
    }
}
