package com.sooka.system.controller;

import java.util.List;

import com.sooka.common.core.controller.BaseController;
import com.sooka.common.core.domain.AjaxResult;
import com.sooka.common.core.page.TableDataInfo;
import com.sooka.common.enums.BusinessType;
import com.sooka.common.utils.poi.ExcelUtil;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.sooka.common.annotation.Log;
import com.sooka.system.domain.TgjjGrdkzhbdxx;
import com.sooka.system.service.ITgjjGrdkzhbdxxService;

/**
 * 个人贷款账户变动信息Controller
 * 
 * @author lei
 * @date 2021-11-16
 */
@Controller
@RequestMapping("/system/grdkzhbdxx")
public class TgjjGrdkzhbdxxController extends BaseController
{
    private String prefix = "system/grdkzhbdxx";

    @Autowired
    private ITgjjGrdkzhbdxxService tgjjGrdkzhbdxxService;

    @RequiresPermissions("system:grdkzhbdxx:view")
    @GetMapping()
    public String grdkzhbdxx()
    {
        return prefix + "/grdkzhbdxx";
    }

    /**
     * 查询个人贷款账户变动信息列表
     */
    @RequiresPermissions("system:grdkzhbdxx:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TgjjGrdkzhbdxx tgjjGrdkzhbdxx)
    {
        startPage();
        List<TgjjGrdkzhbdxx> list = tgjjGrdkzhbdxxService.selectTgjjGrdkzhbdxxList(tgjjGrdkzhbdxx);
        return getDataTable(list);
    }

    /**
     * 导出个人贷款账户变动信息列表
     */
    @RequiresPermissions("system:grdkzhbdxx:export")
    @Log(title = "个人贷款账户变动信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TgjjGrdkzhbdxx tgjjGrdkzhbdxx)
    {
        List<TgjjGrdkzhbdxx> list = tgjjGrdkzhbdxxService.selectTgjjGrdkzhbdxxList(tgjjGrdkzhbdxx);
        ExcelUtil<TgjjGrdkzhbdxx> util = new ExcelUtil<TgjjGrdkzhbdxx>(TgjjGrdkzhbdxx.class);
        return util.exportExcel(list, "grdkzhbdxx");
    }

    /**
     * 新增个人贷款账户变动信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存个人贷款账户变动信息
     */
    @RequiresPermissions("system:grdkzhbdxx:add")
    @Log(title = "个人贷款账户变动信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TgjjGrdkzhbdxx tgjjGrdkzhbdxx)
    {
        return toAjax(tgjjGrdkzhbdxxService.insertTgjjGrdkzhbdxx(tgjjGrdkzhbdxx));
    }

    /**
     * 修改个人贷款账户变动信息
     */
    @GetMapping("/edit/{ID}")
    public String edit(@PathVariable("ID") Long ID, ModelMap mmap)
    {
        TgjjGrdkzhbdxx tgjjGrdkzhbdxx = tgjjGrdkzhbdxxService.selectTgjjGrdkzhbdxxById(ID);
        mmap.put("tgjjGrdkzhbdxx", tgjjGrdkzhbdxx);
        return prefix + "/edit";
    }

    /**
     * 修改保存个人贷款账户变动信息
     */
    @RequiresPermissions("system:grdkzhbdxx:edit")
    @Log(title = "个人贷款账户变动信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TgjjGrdkzhbdxx tgjjGrdkzhbdxx)
    {
        return toAjax(tgjjGrdkzhbdxxService.updateTgjjGrdkzhbdxx(tgjjGrdkzhbdxx));
    }

    /**
     * 删除个人贷款账户变动信息
     */
    @RequiresPermissions("system:grdkzhbdxx:remove")
    @Log(title = "个人贷款账户变动信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tgjjGrdkzhbdxxService.deleteTgjjGrdkzhbdxxByIds(ids));
    }
}
